from pyeasyga import pyeasyga


def add_numbers(num1, num2):
    return num1 + num2


def subtract_numbers(num1, num2):
    return num1 - num2


def multiply_numbers(num1, num2):
    return num1 * num2


def divide_numbers(num1, num2):
    return num1 / num2


data = [('pear', 50), ('apple', 35), ('banana', 40)]

ga = pyeasyga.GeneticAlgorithm(data)        # initialise the GA with data


def fitness(individual, data):
    fitness = 0
    if individual.count(1) == 2:
        for selected, (fruit, weight) in zip(individual, data):
            if selected:
                fitness += weight
    return fitness


ga.fitness_function = fitness               # set the GA's fitness function


ga.run()                                    # run the GA



from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    'Programming Language :: Python :: 3',
]

setup(
    name='decentgradients',
    version='0.0.2',
    description='Calculations',
    long_description='Description to come',
    url='',
    author='Benjamin Kjær',
    author_email='',
    license='MIT',
    classifiers=classifiers,
    keywords='',
    packages=find_packages(),
    install_requires=['']
)
